@@ -12,7 +12,7 @@ extends 'HTML::TreeBuilder';
 use HTML::Linear::Element;
 use HTML::Linear::Path;
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 
 has _list       => (
@@ -130,11 +130,13 @@ sub deparse {
         );
     }
 
-    my %uniq;
+    my (%uniq, %uniq_strict, %is_groupable);
     for my $child ($node->content_list) {
         if (ref $child) {
             my $l = $self->deparse($child, [ @{$path}, $level ]);
-            push @{$uniq{$l->as_xpath(1)}}, $l->address;
+            push @{$uniq{$l->as_xpath}}, $l->address;
+            push @{$uniq_strict{$l->as_xpath(1)}}, $l->address;
+            $is_groupable{$l->address} = $l->is_groupable;
         } else {
             $self->add_element(
                 HTML::Linear::Element->new({
@@ -147,15 +149,33 @@ sub deparse {
         }
     }
 
-    while (my ($xpath, $address) = each %uniq) {
-        next if not $self->_strict and 2 > scalar @{$address};
+    my %count;
+    while (my ($xpath, $address) = each %uniq_strict) {
+        my $i = 1;
+        for my $addr (@{$address}) {
+            $count{$addr} = $i;
+        } continue {
+            ++$i;
+        }
+    }
 
-        my $i = 0;
-        $self->_uniq->{$_} =
-            HTML::Linear::Path::_wrap(array     => '[')
-            . HTML::Linear::Path::_wrap(number  => ++$i)
-            . HTML::Linear::Path::_wrap(array   => ']')
-                for @{$address};
+    while (my ($xpath, $address) = each %uniq) {
+        if (
+            grep { $count{$_} > 1 } @{$address}
+            #or ($self->_strict and $self->_shrink)  # less verbose; unstable
+            or $self->_shrink                       # verbose; stable
+            or 1 < scalar @{$address}
+        ) {
+            my $i = 1;
+            for my $addr (@{$address}) {
+                    $self->_uniq->{$addr} =
+                    HTML::Linear::Path::_wrap(array     => '[')
+                    . HTML::Linear::Path::_wrap(number  => $is_groupable{$addr} ? $i : $count{$addr})
+                    . HTML::Linear::Path::_wrap(array   => ']');
+            } continue {
+                ++$i;
+            }
+        }
     }
 
     return $level;
@@ -177,7 +197,7 @@ HTML::Linear - represent HTML::Tree as a flat list
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
